# Random Beacon Feed AEA

An agent that fetches a decentralised random beacon value. 

## Description

This agent uses the `fetchai/fetch_beacon` skill to get the latest value of a decentralised random beacon.
